@@ -40,6 +40,7 @@ def _season_type_from_name(name: str) -> SeasonType:
         or "2004-2005 Barclays Premier League" in name
         or "2003-2004 Barclays Premier League" in name
         or "2002-2003 Barclays Premier League" in name
+        or "2001-2002 Barclays Premier League" in name
     ):
         return SeasonType.REGULAR
     if name == "Preseason" or "Spring Training" in name:
@@ -112,6 +113,12 @@ class ESPNLeagueModel(LeagueModel):
                 competitions.extend(grouping["competitions"])
 
         for competition in competitions:
+            if "status" in competition:
+                status_response = self.session.get(competition["status"]["$ref"])
+                status_response.raise_for_status()
+                status = status_response.json()
+                if not status["type"]["completed"]:
+                    continue
             game_model = create_espn_game_model(
                 competition,
                 week_count,
