@@ -698,6 +698,11 @@ def _create_hkjc_hkjc_team_model(
         second_chance_points=None,
         plus_minus=None,
         version=version,
+        set_one_points=None,
+        set_two_points=None,
+        set_three_points=None,
+        set_four_points=None,
+        set_five_points=None,
     )
 
 
